# Solana/Learn Me A Solana

In this era where technology is ever-changing, it seems like humanity has become as anxious and impulsive as it has never been before. When the morning sun pierces through layers of clouds and casts warm shadows on the ground, I always think back to 2017, which was the first bull market I experienced in the cryptocurrency world. My friends and I would meticulously study each project's whitepaper, seek out its valuable aspects, and eventually decide whether it was worth being an early investor in it. Time has passed quickly since then, and solana and meme coins have become the main talking points of this bull market. Today, a project's average lifespan might be just one to two days, with only a few hundred users, and soon it would catch no one's attention and lie in a corner where no one cares until it dies.

This *Solana: Learn Me A Solana*, unlike ordinary books on blockchain that captivate readers, is not a fast path to wealth investment manual. Its core concept is very simple: I will show readers how solana constructs a digital civilization. Solana's design philosophy differs from bitcoin or ethereum in some ways; even to say that it diverges in certain fundamental ideas is somewhat accurate. Regardless of whether we agree with it or reject it, we must first understand it.

Perhaps it's curiosity about the unknown or anticipation for the possible. Having waited many years, I have decided again to write a book.

**Supporting code**

The course primarily uses python language. In the first chapter, we will use pabtc, which is a Bitcoin library. In the following chapters, we will mainly use Solana's pxsol library. These two libraries are written by the same person as this book.

- Pabtc: <https://github.com/mohanson/pabtc>
- Pxsol: <https://github.com/mohanson/pxsol>

**Language**

This book is available in Chinese and English.

- [English](https://github.com/mohanson/pxsol/tree/master/doc)
- [Chinese](http://accu.cc/content/solana/foreword/)

**Small Sponsorship**

- SOL: `Dd9i1im9RmaaxmdSrezjN4unqAPLF4HQGEgGrNDGKhtN`
